/* -*-C++-*- */
/*
 *  Copyright (c) 1999 Regents of the University of California.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 */

#include "ACLAuthorizer.h"
#include <iostream>
#include <fstream>

using std::string;
using std::pair;
using std::ifstream;


/* -------------------------------------------------------------------
 *  ACLAuthorizer
 *
 * ------------------------------------------------------------------- */

ACLAuthorizer::ACLAuthorizer(const string& file)
    : SimpleACLAuthorizer(file)
{
    readACLFile(file.c_str());
}

ACLAuthorizer::ACLAuthorizer(const char* file)
    : SimpleACLAuthorizer(file)
{
    readACLFile(file);
}

ACLAuthorizer::~ACLAuthorizer( void )
{
}


/* -------------------------------------------------------------------
 *  parseEntry
 * 
 * ------------------------------------------------------------------- */
void
ACLAuthorizer::parseEntry(string& name, string& rights)
{
    if (name.substr(0, 4) != "name")
	throw string("Bad name entry in the acl file");

    string newName;
    removeWS(name.substr(4), newName);

    if (rights.substr(0, 6) != "rights")
	throw string("Bad rights entry in the acl file");

    string newRights;
    removeWS(rights.substr(6), newRights);
    aclMap[newName] = newRights;
}


/* -------------------------------------------------------------------
 *  checkAction
 *
 * ------------------------------------------------------------------- */

bool 
ACLAuthorizer::checkAction(string& rqstAct, string& actList)
{
    string::size_type indx = 0;
    string::size_type first = 0;
    while (indx != string::npos)
    {
	indx = actList.find(',', first);
	if (indx != string::npos)
	{
	    string act = actList.substr(first, indx - first);
	    first = indx + 1;
	    string newAct;
	    removeWS(act, newAct);
	    if (newAct == rqstAct)
	    {
		return true;
	    }
	}
	else
	{ // this is to catch the last entry
	    string act = actList.substr(first, actList.length() - first);
	    string newAct;
	    removeWS(act, newAct);
	    if (newAct == rqstAct)
	    {
		return true;
	    }
	}
    }
    return false;
}


/* -------------------------------------------------------------------
 *  readACLFile
 *
 * ------------------------------------------------------------------- */

void
ACLAuthorizer::readACLFile(const char* file)
{
    ifstream inStrm(file);

    if (! inStrm) 
	throw string("Unable to open the ACL file");

    string line1, line2, tmp;

    while (!inStrm.eof()){
	std::getline(inStrm, line1);
	removeWS(line1, tmp);
	if (tmp == "" || tmp[0] == '#')
	    continue;

	line1 = tmp;
        do{
	    std::getline(inStrm, line2);
	    removeWS(line2, tmp);
        }while((tmp == "" || tmp[0] == '#') && !inStrm.eof());

	line2 = tmp;
	parseEntry(line1, line2);
    }
}
