/* -*-C++-*- */
/*
 *  Copyright (c) 1999 Regents of the University of California.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 *  $Id: securetcp.h,v 1.7 2001/06/14 18:37:46 boverhof Exp $
 */

#ifndef securetcp_h
#define securetcp_h

#include "Authorizer.h"
#include "SimpleACLAuthorizer.h"
#include "ACLAuthorizer.h"
#include "MyDebug.h"
#include "tcpnet.h"
#include "network.h"
#include "openssl/ssl.h"
#include "openssl/x509.h"
#include "SecurityInfo.h"
#include "openssl/err.h"
#include <string>
#include <vector>

typedef std::vector<std::string> rightsVec;
typedef int ( *CallBackPtr )( char* buf, int num, int verify, void *datatoPassBack );


#if SSLEAY_VERSION_NUMBER < 0x0090581fL
#define RAND_add(a,b,c) RAND_seed(a,b)
#define RAND_status() 1
#endif

#if SSLEAY_VERSION_NUMBER >= 0x00904100L
/* Support both OpenSSL 0.9.4 and SSLeay 0.9.0 */
#define OPENSSL_PEM_CB(A,B)  A, B
#else
#define RAND_add(a,b,c) RAND_seed(a,b)
#define OPENSSL_PEM_CB(A,B)  A
#endif

using std::string;

class SecureTcp: public MyDebug  {

  public:

    SecureTcp( string cert="nettest.pem", string key="key.pem", string ca="CA.pem" );
    virtual ~SecureTcp();
    inline void setCertfilename( const string filename )
    {
	mCertfilename = filename;
    };
    inline void setKeyfilename( const string filename )
    {
	mKeyfilename = filename;
    };
    inline void setCAfilename( const string ca )
    {
	mCAfilename = ca;
    };

    void setPassword_cb( CallBackPtr fPtr );
    bool init( bool server=true, const string addr="" );
    int doAccept( SecurityInfo* secInfo, TCPNet *mySock_p );
    int doAccept( SecurityInfo* secInfo, struct timeval *timeout, TCPNet *mySock_p );
    int doConnect( SecurityInfo* secInfo, const string hostname );
    int doBlockedAccept( SecurityInfo* secInfo, TCPNet *mySock_p );
    void closeClientSock();
    void closeSocket();
    int parseDN( char* newDN, const char* oldDN );
    void writen( char *msg, int len );
    void readn( char *buf, int len );

    inline bool isServer(){
	return mIsServer;
    };
    int setRandFile(int i);

    string      getLocalName();
    string      getRemoteName();

  private:

    CallBackPtr func;
    int         mNewsock;
    int         mFlag;
    bool        mIsServer;

    TCPNet     *sock_p;
    SSL        *mCon_p;
    SSL_CTX    *mCtx_p;
    SSL_METHOD *mMeth_p;

    string      mRemoteHost;
    string      mCertfilename;
    string      mKeyfilename;
    string      mCAfilename;
    rightsVec   mRights;
};

#endif
