/* -*-C++-*- */
/*
 *  Copyright (c) 2000 Regents of the University of California.
 *  All rights reserved.
 * 
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley 
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 * 
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 * 
 */
#ifndef IPERFRESULTS_H
#define IPERFRESULTS_H

#include "MyDebug.h"
#include "headers.h"
#include <string>
#include <iosfwd>
#define MAXHOSTLEN 256

class PerfSocket;
class IperfTestInfo;

using std::string;

class IperfResults: public MyDebug
{
  public:
    friend class PerfSocket;

    IperfResults(PerfSocket&, const double, const double, const int32_t, 
			const int32_t, const int32_t, const max_size_t);
    IperfResults(PerfSocket&, const double, const double, const max_size_t);
    IperfResults();
    IperfResults( const IperfResults& );

    virtual ~IperfResults();

    void fillStats(PerfSocket &);
    virtual void printVariables(void) { return; };
    virtual void printResults(void);
    void printResults_Jitter();

#if USE_NETLOGGER
    void netLogResults_ulm(struct _loginfo * Nlh);
    void netLogResults_Jitter_ulm(struct _loginfo * Nlh);
    void replaceSpaces( string& );
#endif

    inline max_size_t getTotalLen( void )
    {
        return rTotalLen;
    };
    inline int getSocket( void )
    {
        return sock;
    };
    inline double getJitter( void )
    {
        return jJitter;
    };
    inline double getJErrorcnt( void )
    {
        return jErrorcnt;
    };
    inline int32_t getJInOutofOrder( void )
    {
        return jInOutofOrder;
    };
    inline int32_t getJInDatagrams( void )
    {
        return jInDatagrams;
    };
    inline pthread_t getGroupID( void )
    {
        return groupID;
    };
    inline double getStartTime( void )
    {
        return rStartTime;
    };
    inline double getEndTime( void )
    {
        return rEndTime;
    };


    inline void setTotalLen( max_size_t temp )
    {
        rTotalLen = temp;
    };
    inline void setSocket( max_size_t temp )
    {
        sock = temp;
    };
    inline void setJitter( double temp )
    {
        jJitter = temp;
    };
    inline void setJErrorcnt( int32_t temp )
    {
        jErrorcnt = temp;
    };
    inline void setJInOutofOrder( int32_t temp )
    {
        jInOutofOrder = temp;
    };
    inline void setJInDatagrams( int32_t temp )
    {
        jInDatagrams = temp;
    };
    inline void setGroupID( pthread_t gID )
    {
        groupID = gID;
    };
    inline void setStartTime( double time )
    {
        rStartTime = time;
    };
    inline void setEndTime( double time )
    {
        rEndTime = time;
    };


  protected:

    string	remoteHost; 
    string	localHost; 
    string 	rTestParam;

    string 	mSender;
    string 	mReceiver;

    string	tBytes;
    string	tSpeed;

    max_size_t  rTotalLen;
    double      rStartTime;
    double	rEndTime;

    double      jJitter;
    int32_t 	jErrorcnt;
    int32_t  	jInOutofOrder;
    int32_t 	jInDatagrams;

    int		sock;
    char 	bwFormat;
    bool        isUDP;
    pthread_t   groupID;
};

#endif
