/* -*-C++-*- */
/*
 *  Copyright (c) 1999 Regents of the University of California.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley 
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 *  $Id: CoordInfo.h,v 1.16 2001/09/02 02:09:18 boverhof Exp $
 */

#ifndef CoordInfo_h
#define CoordInfo_h

#include <string>
#include <iostream>

class Results;
using std::string;

class CoordInfo {
 private:
    const bool mIsTestRequester; // Boolean telling whether this site is requesting tests
    bool mIsTestMaster; // Boolean telling whether this is the test master site
    bool mIsTestSender; // Boolean telling whether this is a test server
    bool mIsTestReceiver; // Boolean telling whether this is a test client
    bool mIsSOTest;

    string mRequesterName; // Boolean telling whether this site is requesting tests
    string mMasterName;
    string mCoordTestHost;  // Other end of the test coordination connection
    string mLocalHost;  // Other end of the test coordination connection

    string mTestSender;
    string mTestReceiver;
    string mTestName;

    string mIperfParams;
    string mPingParams;
    string mMultiParams;
    string mTunedParams;
    string mTraceParams;

    string mKeyfilename;    // The file to find this site's key
    string mCertfilename;   // The file to find this site's certificate

    Results *results_p;

 public:
    CoordInfo(void);
    CoordInfo(const bool, const string);
    CoordInfo(const CoordInfo&);
    virtual ~CoordInfo(void);
    void printVariables( void );
/*
    CoordInfo& operator=( const CoordInfo& cInfo );
*/
    inline void setIsTestMaster( bool mIs )
    {
	mIsTestMaster = mIs;
    };
    inline void setIsTestSender( bool mIs )
    {
	mIsTestSender = mIs;
    };
    inline void setIsTestReceiver( bool mIs )
    {
	mIsTestReceiver = mIs;
    };
    inline void setIsSOTest( bool mIs )
    {
    	mIsSOTest = mIs;
    };

    inline void setTestName( const string test )
    {
	mTestName = test;
    };
    inline void setIperfParams( const string params )
    {
	mIperfParams = params;
    };
    inline void setPingParams( const string params )
    {
	mPingParams = params;
    };
    inline void setMultiParams( const string params )
    {
	mMultiParams = params;
    };
    inline void setTunedParams( const string params )
    {
	mTunedParams = params;
    };
    inline void setTraceParams( const string params )
    {
	mTraceParams = params;
    };

    inline void setLocalHost( const string name )
    {
	mLocalHost = name;
    };
    inline void setCoordTestHost( const string name )
    {
	mCoordTestHost = name;
    };
    inline void setRequesterName( const string name )
    {
	mRequesterName = name;
    };
    inline void setMasterName( const string host )
    {
        mMasterName = host;
    };
    inline void setTestSender( const string host )
    {
        mTestSender = host;
    };
    inline void setTestReceiver( const string host )
    {
        mTestReceiver = host;
    };
    inline void setResults_p( Results* rptr )
    {
	results_p = rptr;
    };

    inline bool getIsTestRequester(void) const 
    {
	return mIsTestRequester; 
    };
    inline bool getIsTestMaster(void) const 
    {
	return mIsTestMaster; 
    };
    inline bool getIsTestSender(void) const
    {
        return mIsTestSender;
    };
    inline bool getIsTestReceiver(void) const
    {
        return mIsTestReceiver;
    };
    inline bool getIsSOTest(void) const
    {
    	return mIsSOTest;
    };

    inline string getTestName(void) const
    {
	return mTestName;
    };
    inline string getIperfParams(void) const
    {
	return mIperfParams;
    };
    inline string getPingParams(void) const
    {
	return mPingParams;
    };
    inline string getMultiParams(void) const 
    {
	return mMultiParams;
    };
    inline string getTunedParams(void) const
    {
	return mTunedParams;
    };
    inline string getTraceParams(void) const
    {
	return mTraceParams;
    };

    inline string getLocalHost(void) const
    {
	return mLocalHost;
    };
    inline string getCoordTestHost(void) const
    {
	return mCoordTestHost;
    };

    inline string  getRequesterName( void ) const
    {
        return mRequesterName;
    };
    inline string  getMasterName( void ) const
    {
        return mMasterName;
    };
    inline string  getTestSender( void ) const
    {
        return mTestSender;
    };
    inline string  getTestReceiver( void ) const 
    {
        return mTestReceiver;
    };

    inline Results* getResults_p( void )
    {
	return results_p;
    };
};

#endif
