/* -*-C++-*- */
/*
 *  Copyright (c) 1999 Regents of the University of California.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley 
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 *  $Id: TestModule.h,v 1.7 2001/08/29 01:23:53 jason Exp $
 */

#ifndef TestModule_h
#define TestModule_h

#include "config.h"
#include "MyDebug.h"
#include "MyThread.h"
#include "CoordInfo.h"
#include "Listener.hpp"


class TestModule: public MyDebug, public MyThread {
 private:
    CoordInfo      *c_info_ptr;
    pthread_mutex_t data_mutex;
    pthread_mutex_t listener_mutex;

 public:
    TestModule(void);
    TestModule(CoordInfo);
    virtual ~TestModule(void);
    void startTest( CoordInfo );
    virtual void ThreadMain( void );
    virtual void Cleanup( void );

 private:
    void doTest( CoordInfo& );
    int  doTest_Iperf( CoordInfo& );
    int  doTest_Udpping( CoordInfo& );
    int  doTest_Multiping( CoordInfo& );
    int  doTest_Tuned( CoordInfo& );
//#ifdef PATH_TRACEROUTE
    void doTest_Traceroute( CoordInfo& );
//#endif
#ifdef PATH_PIPECHAR
    void doTest_Pipechar( CoordInfo& );
#endif
};

#endif
