/* -*-C++-*- */
/*
 *  Copyright (c) 1999 Regents of the University of California.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 */

#include "PingTestInfo.h"
#include <iostream>
#include <cstring>

using std::endl;
using std::cerr;
using std::ostream;

/* ---------------------------------------------------------
 *  PingTestInfo: Defines the UDP and IP multicast 
 *		  ping test variables.
 * ---------------------------------------------------------*/

PingTestInfo::PingTestInfo( void )
    : TestInfo(false, string(""), string(""), 3642, 1024, 10.0, Timed, 10.0),
      mMcastTtl(1), mSendRate(20), mMcastAddr("")
{
    setClassName("PingTestInfo");
}

PingTestInfo::PingTestInfo( const TestInfo& curinfo )
    : TestInfo( curinfo ), mMcastTtl(1), mSendRate(20), mMcastAddr("")
{
} 

PingTestInfo::~PingTestInfo(void)
{
}


/* -------------------------------------------------------------------
 *  setUserParams:  mTest_Params must be set before enter this function
 *
 * ------------------------------------------------------------------- */

void
PingTestInfo::setUserParams( void )
{
    //string tmpParam( params );
    string tmpParam( mTest_Params );
    string tokenDelims( "-" );
    string tokenNum( "0123456789" );
    string number;
    string::size_type begIdx;

    printDebug(2, "SetUserParams params: %s\n", tmpParam.c_str());

    begIdx = tmpParam.find_first_of( tokenDelims, 0 );
    if( begIdx == string::npos )
        return;

    while( true )
    {
        begIdx = tmpParam.find_first_not_of( tokenDelims, begIdx );
        if( begIdx == string::npos )
            return;

        printDebug(2, "SetUserParams option: \n");

        switch ( tmpParam[begIdx] )
        {
            // CLIENT & SERVER OPTIONS *****************************
            //case 'd': // delay in seconds
            //    getToken( number, tmpParam, tokenNum, begIdx );
            //    delay_secs = atoi( number.c_str() );
            //    break;
            case 'm': // multicast ip address
                getToken( number, tmpParam, tokenNum, begIdx );
		mMcastAddr = number;
                break;
	    case 'n': // Test Amount
                getToken( number, tmpParam, tokenNum, begIdx );
		mTestAmount = atof( number.c_str() );
		break;
	    case 'p': // Test Amount
                getToken( number, tmpParam, tokenNum, begIdx );
		mPort = atoi( number.c_str() );
		break;
            default:
                cerr<<"Error Incorrect parameter: "<< endl;
                break;
        }

        begIdx = tmpParam.find_first_of( tokenDelims, begIdx );
        if( begIdx == string::npos )
            break;
    }

    return;
}


/* -------------------------------------------------------------------
 *  printVariables:
 *
 * ------------------------------------------------------------------- */

ostream&
PingTestInfo::printVariables(ostream& strm)
{
    strm << "PingTestInfo::printVariables(ostream)" << endl;
    strm << "Multicast TTL     = " << mMcastTtl << endl;
    strm << "Send Rate         = " << mSendRate << endl;
    strm << "Multicast Address = " << mMcastAddr << endl << endl;;
    TestInfo::printVariables(strm);
    return strm;
}
