/* -*-C++-*- */
/*
 *  Copyright (c) 1999 Regents of the University of California.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley
 *       National Laboratory.
 *  4. Neither the name of the University nor of the Laboratory may be used
 *     to endorse or promote products derived from this software without
 *     specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 */

#ifndef udpping_h
#define udpping_h

#include <sys/time.h>
#include "udpnet.h"
#include "MyDebug.h"
#include "PingTestInfo.h"

//class PingResults;
class Results;

#define  AVGWINDOW 16


class UDPPing : public MyDebug
{
  public:
    //UDPPing( PingTestInfo *testinf );
    UDPPing( PingTestInfo testinf );
    virtual ~UDPPing();

    double calculateRTT( char *pingmsg, struct timeval *rcvtime);

    //virtual void ThreadMain( void );  // defines the routine executed by pthread_create
    void ThreadMain( void );  // defines the routine executed by pthread_create
    //virtual void Cleanup( void );  // intended to define cleanup actions for when thread is destroyed

    double printStats( void );  // print the current ping statistics
    double getAverageRTT( void );  // returns the current average round trip time
    void   endTest( void );
    void   printResults(void);
    void   printVariables( void );
 
  protected:
    int sendPingTest( void );   // server side of the ping tester (called by ThreadMain)
    int bouncePingTest( void ); // client side of the ping tester (called by ThreadMain)

  private:
    int             mDelaypings;   // how many msecs to delay between each ping test (
                                   // minimum delay will be the round trip time
    //pthread_mutex_t mStats_mutex;  // a mutex protecting the ping statistics variables
    double          mLastrtt[AVGWINDOW];   // the most recent ping results
    int             mNumbertests;  // how many ping tests have been run so far
    int             mTestlimit;    // number of ping tests to run
    UDPNet          mUdpcon;       // the network connection the pings are sent on
    //pthread_t       mThread_id;    // the id of this thread
    PingTestInfo    mPinginf;      // the properties for this ping test
    //PingResults     mPingResults;
};

#endif
