//C++

#include <cstdlib>
#include <cstdio>
#include <unistd.h>
#include <memory.h>
#include <cerrno>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>
#include "openssl/ssl.h"
#include "openssl/err.h"

#define CHK_NULL(x) if ((x)==NULL) exit (1)
#define CHK_ERR(err,s) if ((err)==-1) { perror(s); exit(1); }
#define CHK_SSL(err) if ((err)==-1) { ERR_print_errors_fp(stderr); exit(2); }

#define CERTF "nettest.pem"
#define KEYF  "key.pem"

int main()
{
    int err;
    int sd;
    struct sockaddr_in sa;
    SSL_CTX* ctx;
    SSL*     ssl;
    int verify = SSL_VERIFY_PEER;
    X509*    server_cert;
    char*    str;
    char     buf [4096];
    SSL_METHOD *meth;

    SSLeay_add_ssl_algorithms();
    meth = SSLv3_client_method();
    SSL_load_error_strings();
    ctx = SSL_CTX_new (meth);
    CHK_NULL(ctx);
    if (SSL_CTX_use_certificate_file(ctx, CERTF, SSL_FILETYPE_PEM) <= 0) {
      ERR_print_errors_fp(stderr);
      exit(3);
    }
    if (SSL_CTX_use_PrivateKey_file(ctx, KEYF, SSL_FILETYPE_PEM) <= 0) {
      ERR_print_errors_fp(stderr);
      exit(4);
    }

    if (!SSL_CTX_check_private_key(ctx)) {
      fprintf(stderr,"Private key does not match the certificate public key\n");
      exit(5);
    }
    SSL_CTX_set_verify(ctx, verify, NULL);
    SSL_CTX_load_verify_locations(ctx, "CA.pem", NULL);
    sd = socket (AF_INET, SOCK_STREAM, 0);       
    CHK_ERR(sd, "socket");
    memset (&sa, '\0', sizeof(sa));
    sa.sin_family      = AF_INET;
    sa.sin_addr.s_addr = inet_addr ("216.101.242.18");   /* Server IP */
    sa.sin_port        = htons     (55556);          /* Server Port number */
    err = connect(sd, (struct sockaddr*) &sa, sizeof(sa));                   
    CHK_ERR(err, "connect")
    ssl = SSL_new (ctx);                         
    CHK_NULL(ssl);
    SSL_set_fd (ssl, sd);
    err = SSL_connect (ssl);                     
    CHK_SSL(err);
    printf ("SSL connection using %s\n", SSL_get_cipher (ssl));
    close (sd);
    SSL_free (ssl);
    SSL_CTX_free (ctx);
}
